//
//  PageModeViewController.m
//  SHC
//
//  Created by Ambiga on 18/05/15.
//  Copyright (c) 2015 Ambiga. All rights reserved.
//

#import "PageModeViewController.h"
#define TREBUCHET_MS @"Trebuchet MS"


@interface PageModeViewController ()
{
    NSMutableArray * mArrayXs;
    NSMutableArray * mArrayYs;
    NSMutableArray * mArrayWs;
    NSMutableArray * mArrayHs;
    
    NSString * nSelectedXPos;
    NSString * nSelectedYPos;
    NSString * nSelectedWidth;
    NSString * nSelectedHeight;
    //UI to show and hide number pad for text fields
    UIToolbar *toolBar;
    UIBarButtonItem *barItemHideNumPad, *barItemClearText;
}
@end

@implementation PageModeViewController

@synthesize printer;


- (void)loadView{
    [super loadView];
    if ([self respondsToSelector:@selector(edgesForExtendedLayout)]) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        self.extendedLayoutIncludesOpaqueBars = NO;
        self.automaticallyAdjustsScrollViewInsets = NO;
    }
    self.navigationController.toolbarHidden = YES ;
    UILabel *printCharacters = [[UILabel alloc]initWithFrame:CGRectMake(self.view.frame.origin.x + 20, self.view.frame.origin.y + 5, 200,30)];
    [printCharacters setText:@"Print Characters"];
    [printCharacters setTextAlignment: NSTextAlignmentLeft];
    [printCharacters setBackgroundColor:[UIColor clearColor]];
    [printCharacters setTextColor: [UIColor blackColor]];
//    if([[UIDevice currentDevice].model containsString:@"iPhone"])
    if([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPhone)
        [printCharacters setFont:[UIFont fontWithName: @"Trebuchet MS" size: 18]];
    else
        [printCharacters setFont:[UIFont fontWithName: @"Trebuchet MS" size: 20]];
    [self.view addSubview:printCharacters];
    //Textview to type the command
    commandText = [[UITextView alloc]initWithFrame:CGRectMake(self.view.frame.origin.x + 20, self.view.frame.origin.y + 5 + printCharacters.frame.size.height, self.view.frame.size.width - 40, self.view.frame.size.height/5)];
    commandText.layer.borderColor = [UIColor darkGrayColor].CGColor;
    commandText.layer.cornerRadius = 5;
    commandText.layer.borderWidth = 1;
    commandText.font = [UIFont systemFontOfSize:18];
    commandText.text = @"0123456789\nABCDEFGHIJKLMNOPQRSTUVWXYZ";
    commandText.textColor = [UIColor blackColor];
    commandText.returnKeyType = UIReturnKeyDefault;
    [self.view addSubview:commandText];
    
    
    
    printButton = [[UIButton alloc]initWithFrame: CGRectMake(((self.view.frame.size.width - (self.view.frame.size.width/2)) /2), self.view.frame.origin.y + self.view.frame.size.height - 134, self.view.frame.size.width /2, 50)];
    [printButton setTitle:@"Print" forState:UIControlStateNormal];
    printButton.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    printButton.backgroundColor = [UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0];
    [printButton addTarget:self action:@selector(sendCommandToPrinter) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:printButton];
    [self.view setBackgroundColor:[UIColor whiteColor]];
    
    commandText.delegate = self;
}

- (void) loadToolbar
{
    NSDictionary *attributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                [UIFont fontWithName: TREBUCHET_MS size: 18], NSFontAttributeName,
                                [UIColor darkGrayColor], NSForegroundColorAttributeName,
                                nil];
    
    //toolbar
    UIBarButtonItem *barItemSpace = [[UIBarButtonItem alloc]
                                     initWithBarButtonSystemItem: UIBarButtonSystemItemFlexibleSpace
                                     target: nil
                                     action: nil];
    
    barItemHideNumPad = [[UIBarButtonItem alloc]
                         initWithTitle: @"Done"
                         style: UIBarButtonItemStyleDone
                         target: self
                         action: nil];
    [barItemHideNumPad setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    barItemClearText = [[UIBarButtonItem alloc]
                        initWithTitle: @"Clear"
                        style: UIBarButtonItemStyleDone
                        target: self
                        action: nil];
    [barItemClearText setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    const float heightToolbar = 40.0f;
    toolBar = [[UIToolbar alloc] initWithFrame:
               CGRectMake(0, 0, self.view.frame.size.width, heightToolbar)];
    [toolBar setItems: [NSArray arrayWithObjects:
                        barItemHideNumPad, barItemSpace,
                        barItemClearText, nil]];
}
- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    [self updatePageModeUI];
    if(printer.bluetoothAccessory){
        SAM4SPrintIO *sam4sIO = (SAM4SPrintIO *)printer.printIO;
        printer.printIO.connection.delegate = self;
        [sam4sIO PrinterSetup];
        [printer.printIO.connection sendDataToPrinter:[sam4sIO getDataTosend:sam4sIO]];
    }
}

- (void)updatePageModeUI
{
    mArrayXs = [[NSMutableArray alloc] init];
    mArrayYs = [[NSMutableArray alloc] init];
    mArrayWs = [[NSMutableArray alloc] init];
    mArrayHs = [[NSMutableArray alloc] init];
    
    for (int i = 0; i <= 255; i++)
    {
        [mArrayXs addObject:[NSString stringWithFormat:@"%d", i]];
        [mArrayYs addObject:[NSString stringWithFormat:@"%d", i]];
    }
    for (int i = 0; i <= 512; i++)
    {
        [mArrayWs addObject:[NSString stringWithFormat:@"%d", i]];
        [mArrayHs addObject:[NSString stringWithFormat:@"%d", i]];
    }
    CGRect rect = CGRectMake(self.view.frame.origin.x + 20, commandText.frame.size.height + 85, self.view.frame.size.width/4 - 15, 100);
    for (int i = 0; i <= 3; i++)
    {
        UIPickerView * pickerView =  [[UIPickerView alloc]initWithFrame:rect];
        pickerView.delegate = self;
        pickerView.dataSource = self;
        pickerView.tag = i;
        [pickerView.layer setBorderColor: [UIColor darkGrayColor].CGColor];
        [pickerView.layer setBorderWidth: 1.0f];
        [pickerView.layer setCornerRadius: 5.0f];
        [self.view addSubview:pickerView];
        
        UILabel *label = [[UILabel alloc] initWithFrame: CGRectMake(pickerView.frame.origin.x, pickerView.frame.origin.y - 27, pickerView.frame.size.width, 22)];
        NSString * string = nil;
        switch (i) {
            case 0:
                string = @"X Pos";
                [pickerView selectRow:100 inComponent:0 animated:YES];
                nSelectedXPos = [NSString stringWithFormat:@"%ld",(long)[pickerView selectedRowInComponent:0]];
                break;
                
            case 1:
                string = @"Y Pos";
                [pickerView selectRow:100 inComponent:0 animated:YES];
                nSelectedYPos = [NSString stringWithFormat:@"%ld",(long)[pickerView selectedRowInComponent:0]];
                break;
                
            case 2:
                string = @"Width";
                [pickerView selectRow:300 inComponent:0 animated:YES];
                nSelectedWidth = [NSString stringWithFormat:@"%ld",(long)[pickerView selectedRowInComponent:0]];
                break;
                
            case 3:
                string = @"Height";
                [pickerView selectRow:300 inComponent:0 animated:YES];
                nSelectedHeight = [NSString stringWithFormat:@"%ld",(long)[pickerView selectedRowInComponent:0]];
                break;
                
            default:
                break;
        }
        
        [label setText:string];
//        if([[UIDevice currentDevice].model containsString:@"iPhone"])
        if([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPhone)
            [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 18]];
        else
            [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 20]];
        [label setTextAlignment: NSTextAlignmentCenter];
        [label setBackgroundColor:[UIColor clearColor]];
        [label setTextColor: [UIColor blackColor]];
        [self.view addSubview:label];
        rect.origin.x += rect.size.width + 10;
    }
    
}
- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:YES];
    commandText.delegate = self;
    
}


- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:YES];
    self.navigationController.toolbarHidden = YES ;
    commandText.text = @"0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


#pragma mark - Text View View Delegates
- (BOOL) textViewShouldBeginEditing:(UITextView *)textView
{
    if(commandText)
    {
        if(!toolBar)
        {
            [self loadToolbar];
        }
        
        [barItemHideNumPad setTarget: textView];
        [barItemHideNumPad setAction: @selector(resignFirstResponder)];
        
        [barItemClearText setTarget: self];
        [barItemClearText setAction:@selector(clearText)];
        
        [textView setInputAccessoryView: toolBar];
    }
    
    return YES;
}

- (void) clearText
{
    commandText.text = nil;
    
}
- (void)textViewDidBeginEditing:(UITextView *)textView
{
    //Implementation not required
}


- (void)textViewDidEndEditing:(UITextView *)textView{
    commandText.text = textView.text ;
}


- (BOOL)textView:(UITextView *)textView shouldChangeTextInRange:(NSRange)range
 replacementText:(NSString *)text
{
    // Any new character added is passed in as the "text" parameter
    if ([text isEqualToString:@"\n"]) {
        // Be sure to test for equality using the "isEqualToString" message
        // [textView resignFirstResponder];
//        commandText.text = [NSString stringWithFormat:@"%@\n",commandText.text];
        [commandText insertText:text];
        // Return FALSE so that the final '\n' character doesn't get added
        return FALSE;
    }
    // For any other character return TRUE so that the text gets added to the view
    return TRUE;
}

- (UIView*) pickerView: (UIPickerView*)pickerView viewForRow: (NSInteger)row forComponent: (NSInteger)component reusingView: (UIView*)view
{
    NSString * string = nil;
    
    switch (pickerView.tag)
    {
        case 0:
            string = [mArrayXs objectAtIndex:row];
            break;
            
        case 1:
            string = [mArrayYs objectAtIndex:row];
            break;
            
        case 2:
            string = [mArrayWs objectAtIndex:row];
            break;
            
        case 3:
            string = [mArrayHs objectAtIndex:row];
            break;
            
        default:
            break;
    }
    UILabel *label = [[UILabel alloc] initWithFrame: CGRectMake(0, 0, pickerView.frame.size.width, 40)];
    [label setText:string];
    [label setTextAlignment: NSTextAlignmentCenter];
    [label setTextColor: [UIColor blackColor]];
    return label;
}

- (NSInteger) pickerView: (UIPickerView*)pickerView numberOfRowsInComponent: (NSInteger)component
{
    int nCount = 0;
    switch (pickerView.tag)
    {
        case 0:
            nCount = (int)[mArrayXs count];
            break;
            
        case 1:
            nCount = (int)[mArrayYs count];
            break;
            
        case 2:
            nCount = (int)[mArrayWs count];
            break;
            
        case 3:
            nCount = (int)[mArrayHs count];
            break;
            
        default:
            break;
    }
    return nCount;
}

- (NSInteger) numberOfComponentsInPickerView: (UIPickerView *)pickerView
{
    return 1;
}


- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    
    switch (pickerView.tag)
    {
        case 0:
            nSelectedXPos = [mArrayXs objectAtIndex:row];
            break;
            
        case 1:
            nSelectedYPos = [mArrayYs objectAtIndex:row];
            break;
            
        case 2:
            nSelectedWidth = [mArrayWs objectAtIndex:row];
            break;
            
        case 3:
            nSelectedHeight = [mArrayHs objectAtIndex:row];
            break;
            
        default:
            break;
    }
}

- (NSAttributedString *)pickerView:(UIPickerView *)pickerView attributedTitleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    NSString *title = @"X";
    NSAttributedString *attString = [[NSAttributedString alloc] initWithString:title attributes:@{NSForegroundColorAttributeName:[UIColor whiteColor]}];
    
    return attString;
    
}

- (void)sendCommandToPrinter
{
    if(printer){
        SAM4SPrintIO *sam4sIO = (SAM4SPrintIO *)printer.printIO;
        printer.printIO.connection.delegate = self;
        [sam4sIO PrinterSetup];
        [sam4sIO addPageBegin];
        [sam4sIO addPageArea:[nSelectedXPos intValue]:[nSelectedYPos intValue] :[nSelectedWidth intValue]:[nSelectedHeight intValue]];
        [sam4sIO addTextData:commandText.text];
        [sam4sIO addPageEnd];
        [printer.printIO.connection sendDataToPrinter:[sam4sIO getDataTosend:sam4sIO]];
    }
}

-(void) didReceivedDataFromPrinter:(NSData*)data
{
    NSLog(@"data = %@", [data description]);
}

- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event{
    [self.view endEditing:YES];
    [super touchesBegan:touches withEvent:event];
}
@end
