//
//  PrinterListViewController.m
//  SHC
//
//  Created by Sam4sSDK on 14/05/15.
//  Copyright (c) 2015 Ambiga. All rights reserved.
//

#import "PrinterListViewController.h"
#import "Printer.h"
#import "WiredConnectionManager.h"
#import "Global.h"
#import "SimplePing.h"
#import "SimplePingHelper.h"
#import "SAM4SPrintIO.h"
#import "SamplePrintViewController.h"

#define TREBUCHET_MS @"Trebuchet MS"
#define IS_IPHONE ( [ [ [ UIDevice currentDevice ] model ] isEqualToString: @"iPhone" ] )

@interface PrinterListViewController ()
{
    
    SamplePrintViewController *samplePrintVC;
    BOOL isPrinterAvailable;
    //UI to show and hide number pad for text fields
    UIToolbar *toolBar;
    UIBarButtonItem *barItemHideNumPad, *barItemClearText;
    MBProgressHUD *HUD;
    UIAlertView *alert;
    NSMutableArray *manualEntryIP;
    
}
@end

@implementation PrinterListViewController
@synthesize connectedPrinter;
static NSString *CellIdentifier = @"Cell";
static int count = 0;

- (instancetype) init
{
    self = [super init];
    
    if(self)
    {
        manualEntryIP = [[NSMutableArray alloc]init];
        isPrinterAvailable = NO;
        wiredManager = [ConnectionManager sharedConnectionWithType:ConnectionTypeWiFi delegate:self];
        wiredManager.wireddelegate = self;
        bluetoothManager = [ConnectionManager sharedConnectionWithType:ConnectionTypeBlueTooth delegate:self];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_accessoryDidConnect:) name:EAAccessoryDidConnectNotification object:nil];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(_accessoryDidDisconnect:) name:EAAccessoryDidDisconnectNotification object:nil];
        [[EAAccessoryManager sharedAccessoryManager] registerForLocalNotifications];
        
    }
    
    return self;
}


- (void) loadView
{
    [super loadView];
    NSLog(@"Sam4sSDKloadview");
    if ([self respondsToSelector:@selector(edgesForExtendedLayout)])
    {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        self.extendedLayoutIncludesOpaqueBars = NO;
        self.automaticallyAdjustsScrollViewInsets = NO;
    }
    
    [self.navigationController.navigationBar setBarTintColor:[UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0]];
    [self.navigationController.navigationBar setTitleTextAttributes:[NSDictionary dictionaryWithObject:[UIColor whiteColor] forKey:NSForegroundColorAttributeName]];
    [self.navigationController.navigationBar setTintColor:[UIColor whiteColor]];
    
    
    refreshButton = [[UIBarButtonItem alloc]
                     initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh
                     target:self action:@selector(refreshButtonClicked)];
    self.navigationItem.rightBarButtonItem = refreshButton;
    
    //table header as Segmented Control
    NSArray *itemArray = [NSArray arrayWithObjects: @"Ethernet",@"Bluetooth", nil];
    segmentedControl = [[UISegmentedControl alloc] initWithItems:itemArray];
    [segmentedControl addTarget:self action:@selector(MySegmentControlAction:) forControlEvents: UIControlEventValueChanged];
    segmentedControl.frame = CGRectMake(self.view.frame.size.width/2 - 50 , self.view.frame.origin.y + 67, 300, 50);
    segmentedControl.center = CGPointMake(self.view.frame.size.width/2 - 50, self.view.frame.origin.y + 40);
    //    [segmentedControl setWidth:150.0 forSegmentAtIndex:0];
    //    [segmentedControl setWidth:150.0 forSegmentAtIndex:1];
    segmentedControl.enabled = YES;
    segmentedControl.selected = YES;
    segmentedControl.momentary = NO;
    segmentedControl.center = CGPointMake(self.view.frame.size.width/2, self.view.frame.origin.y + 45);
    [segmentedControl setTranslatesAutoresizingMaskIntoConstraints:NO];
    segmentedControl.selectedSegmentIndex = 0;
    segmentedControl.tintColor = [UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0];
    [self.view addSubview:segmentedControl];
    
    //set frame fo the tableView
    CGFloat x = self.view.frame.origin.x;
    CGFloat y =  self.view.frame.origin.y + segmentedControl.frame.origin.y + segmentedControl.frame.size.height + 20;
    CGFloat width = self.view.frame.size.width;
    CGFloat height = self.view.frame.size.height - 100;
    CGRect tableFrame = CGRectMake(x, y, width, height);
    
    self.tableView = [[UITableView alloc]initWithFrame:tableFrame style:UITableViewStyleGrouped];
    
    self.tableView.scrollEnabled = YES;
    self.tableView.userInteractionEnabled = YES;
    self.tableView.bounces = YES;
    self.tableView.rowHeight = 80;
    [self.view addSubview:self.tableView];
    
    //toolbar to add the ip address of the printer manually
    self.navigationController.toolbarHidden = YES;
    
    addToolbarView = [[UIView alloc]initWithFrame:CGRectMake(self.view.frame.origin.x, self.tableView.frame.size.height - 64, self.view.frame.size.width, 100)];
    addToolbarView.backgroundColor =[UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0];
    
    ipAddressTextField = [[UITextField alloc]initWithFrame:CGRectMake(self.view.frame.origin.x + 10, addToolbarView.frame.size.height/2 - 15, self.view.frame.size.width/2 + 90, 60)];
    ipAddressTextField.delegate = self;
    ipAddressTextField.borderStyle = UITextBorderStyleRoundedRect ;
    ipAddressTextField.keyboardType = UIKeyboardTypeDecimalPad ;
    ipAddressTextField.placeholder = @"Manually add IP Address";
    ipAddressTextField.center = CGPointMake(self.view.frame.size.width/2 - 30,addToolbarView.frame.size.height/2) ;
    [addToolbarView addSubview:ipAddressTextField];
    
    UIButton * addButton = [[UIButton alloc]initWithFrame:CGRectMake(self.view.frame.size.width-50, addToolbarView.frame.size.height/2 - 15, 50, 60)];
    [addButton setTitle:@"Add" forState:UIControlStateNormal];
    [addButton addTarget:self action:@selector(addIPAddress) forControlEvents:UIControlEventTouchUpInside];
    addButton.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    addButton.contentHorizontalAlignment = UIControlContentHorizontalAlignmentCenter;
    addButton.titleLabel.font = [UIFont fontWithName:@"HelveticaNeue-Light" size:15];
    addButton.backgroundColor = [UIColor whiteColor];
    [addButton setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    addButton.layer.cornerRadius = 5;
    addButton.layer.borderWidth = 1;
    addButton.clipsToBounds = YES;
    addButton.center = CGPointMake(ipAddressTextField.frame.size.width + ipAddressTextField.frame.origin.x + 35 ,addToolbarView.frame.size.height/2) ;
    [addToolbarView addSubview: addButton];
    [self.view addSubview:addToolbarView];
    
    printerListArray = [[NSMutableArray alloc]init];
    
    //self.view.backgroundColor =[UIColor whiteColor];
    //self.tableView.backgroundColor = self.view.backgroundColor;
    
}


- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.tableView.contentInset = UIEdgeInsetsZero;
    if ([[UIDevice currentDevice].systemVersion floatValue] >= 7){
        self.tableView.contentInset = UIEdgeInsetsMake(-35, 0, 0, 0);
    }
    self.automaticallyAdjustsScrollViewInsets = NO;
    
    [self.tableView registerClass: [PrinterTableViewCell class] forCellReuseIdentifier: @"Cell"];
    /* For pull to refresh*/
    
    UIRefreshControl *refresh = [[UIRefreshControl alloc] init];
    refresh.attributedTitle = [[NSAttributedString alloc] initWithString:@"Loading..."];
    [refresh addTarget:self action:@selector(refreshView:) forControlEvents:UIControlEventValueChanged];
    [self.tableView addSubview:refresh];
}

-(void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
    [super touchesBegan:touches withEvent:event];
    
    int oldValue =(int)segmentedControl.selectedSegmentIndex;
    [super touchesBegan:touches withEvent:event];
    if ( oldValue == segmentedControl.selectedSegmentIndex )
    {
        //        [self MySegmentControlAction:UISegmentedControlSegmentCenter];
    }
}
-(void)refreshView:(UIRefreshControl *)refresh
{
    refresh.attributedTitle = [[NSAttributedString alloc] initWithString:@"Refreshing Printer List..."];
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:@"MMM d, h:mm a"];
    NSString *lastUpdated = [NSString stringWithFormat:@"Updated on %@", [formatter stringFromDate:[NSDate date]]];
    refresh.attributedTitle = [[NSAttributedString alloc] initWithString:lastUpdated];
    [refresh endRefreshing];
    [self availablePrinters];
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    self.title = @"Printer(s)";
    self.navigationController.toolbarHidden = YES ;
    if(segmentedControl.selectedSegmentIndex == 0)
    {
        addToolbarView.hidden = NO;
        
    }else if (segmentedControl.selectedSegmentIndex == 1)
    {
        addToolbarView.hidden = YES;
        //        [self showBluetoothAccessoryPicker];
    }
    //    UIApplication* app = [UIApplication sharedApplication];
    //    app.networkActivityIndicatorVisible = YES;
    [self availablePrinters];
    
    isPrinterAvailable = NO;
    
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    // unregister for keyboard notifications while not visible.
    isPrinterAvailable = NO;
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:YES];
    [self.tableView setDataSource:self];
    [self.tableView setDelegate:self];
    //    [self availablePrinters];
}

- (void) loadToolbar
{
    NSDictionary *attributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                [UIFont fontWithName: TREBUCHET_MS size: 18], NSFontAttributeName,
                                [UIColor darkGrayColor], NSForegroundColorAttributeName,
                                nil];
    
    //toolbar
    UIBarButtonItem *barItemSpace = [[UIBarButtonItem alloc]
                                     initWithBarButtonSystemItem: UIBarButtonSystemItemFlexibleSpace
                                     target: nil
                                     action: nil];
    
    barItemHideNumPad = [[UIBarButtonItem alloc]
                         initWithTitle: @"Done"
                         style: UIBarButtonItemStyleDone
                         target: self
                         action: nil];
    [barItemHideNumPad setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    barItemClearText = [[UIBarButtonItem alloc]
                        initWithTitle: @"Clear"
                        style: UIBarButtonItemStyleDone
                        target: self
                        action: nil];
    [barItemClearText setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    const float heightToolbar = 40.0f;
    toolBar = [[UIToolbar alloc] initWithFrame:
               CGRectMake(0, 0, self.view.frame.size.width, heightToolbar)];
    [toolBar setItems: [NSArray arrayWithObjects:
                        barItemHideNumPad, barItemSpace,
                        barItemClearText, nil]];
}

#pragma mark - Connection delegate methods
- (void) errorInShowingPrintersPickerView: (NSError*) error
{
}

- (void) deviceConnectionFailure
{
    NSLog(@"deviceConnectionFailure . . .");
    NSLog(@"Sam4sSDKdeviceConnectionFailure . . .");
}

- (void) didPrinterConnected: (Printer*)printer
{
    if(segmentedControl.selectedSegmentIndex == 0 || segmentedControl.selectedSegmentIndex == 1)
    {
        [self availablePrinters];
        [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    }
}

- (void) didPrinterDisconnected: (Printer*)printer
{
    if(connectedPrinter.bluetoothAccessory) //check if the disconnected printer's menu is visible
    {
        if(!connectedPrinter.bluetoothAccessory.isConnected )
        {
            [self showAlert];
        }
        
    }else if (printer.iPAddress)
    {
        [self showAlert];
        
    }
    if(segmentedControl.selectedSegmentIndex == 0 || segmentedControl.selectedSegmentIndex == 1)
    {
        [self availablePrinters];
        [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    }
}
#pragma mark Internal

- (void)_accessoryDidConnect:(NSNotification *)notification {
    EAAccessory *connectedAccessory = [[notification userInfo] objectForKey:EAAccessoryKey];
    [printerListArray addObject:connectedAccessory];
    NSIndexPath *indexPath = [NSIndexPath indexPathForRow:([printerListArray count] - 1) inSection:0];
    [[self tableView] insertRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationLeft];
    [self availablePrinters];
    [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
}

- (void)_accessoryDidDisconnect:(NSNotification *)notification {
    EAAccessory *disconnectedAccessory = [[notification userInfo] objectForKey:EAAccessoryKey];
    
    if (selectedAccessory && [disconnectedAccessory connectionID] == [selectedAccessory connectionID])
    {
        int disconnectedAccessoryIndex = 0;
        if(segmentedControl.selectedSegmentIndex == 1)
        {
            for(EAAccessory *accessory in printerListArray) {
                if ([disconnectedAccessory connectionID] == [accessory connectionID]) {
                    break;
                }
                disconnectedAccessoryIndex++;
            }
        }
        if (disconnectedAccessoryIndex < [printerListArray count]) {
            [printerListArray removeObjectAtIndex:disconnectedAccessoryIndex];
            NSIndexPath *indexPath = [NSIndexPath indexPathForRow:disconnectedAccessoryIndex inSection:0];
            [[self tableView] deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationRight];
            [self availablePrinters];
            [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
            [self showAlert];
        } else {
            NSLog(@"could not find disconnected accessory in accessory list");
            NSLog(@"Sam4sSDKcould not find disconnected accessory in accessory list");
            
        }
        
    }
}

- (void) showBluetoothAccessoryPicker
{
    [printerListArray removeAllObjects];
    if(connectedPrinter.iPAddress)
    {
        [wiredManager disconnectPrinter: connectedPrinter];
        connectedPrinter = nil;
    }
    [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    
    void (^pickerDismissHandler)() = ^ (NSError *error)
    {
        [printerListArray removeAllObjects];
        UIAlertView * alertView = [[UIAlertView alloc]
                                   initWithTitle: @"Error"
                                   message:nil
                                   delegate: nil
                                   cancelButtonTitle: @"Ok" otherButtonTitles: nil];
        switch (error.code) {
            case 0:
                alertView.message = @"AlreadyConnected";
                break;
            case 1:
                alertView.message = @"ResultNotFound";
                //                [alert show];
                break;
            case 2:
                alertView.message = @"ResultCancelled";
                break;
            case 3:
                alertView.message = @"ResultFailed";
                //                [alert show];
                break;
                
            default:
                break;
        }
        
        [printerListArray addObjectsFromArray:[bluetoothManager connectedPrintersNameForBluetooth]];
        [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    };
    
    NSPredicate *predicatePrinterName = nil;
    //    predicatePrinterName = [NSPredicate predicateWithFormat: @"self CONTAINS %@", PRINTER_NAME_PoS];
    [[EAAccessoryManager sharedAccessoryManager]
     showBluetoothAccessoryPickerWithNameFilter: predicatePrinterName
     completion:pickerDismissHandler];
    
}
- (void)showAlertWhenPrinterListIsEmpty
{
    if(printerListArray.count == 0)
    {
        
        UIAlertView * alertView = [[UIAlertView alloc]
                                   initWithTitle: @"No printer is connected!"
                                   message: @"1.Click reload to connect Wifi. \n2.Open Settings -> Bluetooth \n Scan and connect to printers."
                                   delegate: self
                                   cancelButtonTitle: @"Wifi"
                                   otherButtonTitles:@"Bluetooth", nil];
        [alertView show];
        
    }
}

#pragma mark - Tap Gesture Method

- (void)singleTapGestureCaptured:(UITapGestureRecognizer *)gesture
{
    [self.view endEditing:YES];
    [ipAddressTextField resignFirstResponder];
}

- (void)addIPAddress
{
    if(ipAddressTextField.text.length > 0 && [wiredManager isValidIpAddress:ipAddressTextField.text])
    {
        if([printerListArray containsObject:ipAddressTextField.text])
        {
            UIAlertView * alertView = [[UIAlertView alloc]
                                       initWithTitle: @"Info"
                                       message: @"IP Address already available"
                                       delegate: nil
                                       cancelButtonTitle: @"Ok" otherButtonTitles: nil];
            [alertView show];
        }else
        {
            //            [SimplePingHelper ping:selectedIPAddr
            //                            target:self sel:@selector(pingPrinterResult1:)];
            [manualEntryIP addObject:ipAddressTextField.text];
            [printerListArray addObject:ipAddressTextField.text];
        }
    }else if(ipAddressTextField.text.length > 0){
        UIAlertView * alertView = [[UIAlertView alloc]
                                   initWithTitle: @"Error"
                                   message: @"Invalid IP Address"
                                   delegate: nil
                                   cancelButtonTitle: @"OK" otherButtonTitles: nil];
        [alertView show];
    }else if(ipAddressTextField.text.length == 0){
        UIAlertView * alertView = [[UIAlertView alloc]
                                   initWithTitle: @"Error"
                                   message: @"Please fill the IP address"
                                   delegate: nil
                                   cancelButtonTitle: @"OK" otherButtonTitles: nil];
        [alertView show];
        
    }
    selectedIPAddr = ipAddressTextField.text;
    [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    ipAddressTextField.text = @"";
    ipAddressTextField.placeholder = @"Manually add IP Address";
    [ipAddressTextField resignFirstResponder];
}

#pragma mark - List of availble printers via ethernet

- (NSArray *)availablePrinters
{
    NSLog(@"Sam4sSDKavailablePrinters");
    
    [printerListArray removeAllObjects];
    
    if(segmentedControl.selectedSegmentIndex == 0)
    {
        if([manualEntryIP count] > 0){
            printerListArray =  printerListArray = [NSMutableArray arrayWithArray:[manualEntryIP arrayByAddingObjectsFromArray:[wiredManager connectedPrintersIPAddress]]];
            
        }else
        {
            [printerListArray addObjectsFromArray:[wiredManager connectedPrintersIPAddress]];
        }
        
        NSLog(@"Sam4sSDKavailablePrinters %@", printerListArray);
    }
    else
    {
        [printerListArray addObjectsFromArray:[bluetoothManager connectedPrintersNameForBluetooth]];
        
    }
    [self.tableView reloadData];
    return printerListArray;
}

- (void)updateUI:(NSTimer *)timer
{
    @synchronized(self)
    {
        sleep(10);
        [self availablePrinters];
        
    }
    [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
    
}
- (void)refreshButtonClicked
{
    NSLog(@"Sam4sSDKrefreshButtonClicked");
    if([ipAddressTextField isFirstResponder])
        [ipAddressTextField resignFirstResponder];
    HUD = [[MBProgressHUD alloc] initWithView:self.navigationController.view];
    [self.navigationController.view addSubview:HUD];
    
    // Set the hud to display with a color
    HUD.color = [UIColor colorWithRed:0.23 green:0.50 blue:0.82 alpha:0.90];
    
    HUD.delegate = self;
    [HUD showWhileExecuting:@selector(updateUI:) onTarget:self withObject:nil animated:YES];
    
}
#pragma mark TextField Delegates

- (BOOL) textFieldShouldBeginEditing: (UITextField*) textField
{
    if(ipAddressTextField)
    {
        if(!toolBar)
        {
            [self loadToolbar];
        }
        
        [barItemHideNumPad setTarget: textField];
        [barItemHideNumPad setAction: @selector(resignFirstResponder)];
        
        [barItemClearText setTarget: textField];
        [barItemClearText setAction: @selector(clearText)];
        
        [textField setInputAccessoryView: toolBar];
    }
    
    return YES;
}

- (void) clearText
{
    ipAddressTextField.text = @"";
    ipAddressTextField.placeholder = @"Manually add IP Address";
}

- (BOOL)textFieldShouldEndEditing:(UITextField *)textField
{
    return YES;
}


- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    if (textField == ipAddressTextField) {
        return YES;
    }
    return YES;
}


-(void) textFieldDidBeginEditing:(UITextField *)textView
{
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.25f];
    [UIView setAnimationCurve:UIViewAnimationCurveEaseIn];
    CGRect frame = self.view.frame;
    if(IS_IPHONE)
    {
        frame.origin.y =frame.origin.y - 240;
    }
    else
    {
        frame.origin.y =frame.origin.y - 320;
    }
    
    [self.view setFrame:frame];
    [UIView commitAnimations];
    
}


-(void) textFieldDidEndEditing:(UITextField *)textView
{
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.25f];
    [UIView setAnimationCurve:UIViewAnimationCurveEaseOut];
    CGRect frame = self.view.frame;
    if(IS_IPHONE)
    {
        frame.origin.y = frame.origin.y + 240;
    }
    else
    {
        frame.origin.y = frame.origin.y + 320;
    }
    [self.view setFrame:frame];
    [UIView commitAnimations];
    ipAddressTextField.placeholder = @"Manually add IP Address";
    
}


#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [printerListArray count];
}


- (PrinterTableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    PrinterTableViewCell *cell = (PrinterTableViewCell*)[self.tableView dequeueReusableCellWithIdentifier: CellIdentifier forIndexPath: indexPath];
    
    if(!cell)
    {
        cell = [[PrinterTableViewCell alloc] initWithStyle: UITableViewCellStyleDefault reuseIdentifier: CellIdentifier];
    }
    
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    if(printerListArray){
        if(segmentedControl.selectedSegmentIndex == 0)
        {
            [cell setPrinterName:[printerListArray objectAtIndex:indexPath.row]];
        }else
        {
            EAAccessory *accessory = [printerListArray objectAtIndex: indexPath.row];
            [cell setPrinterName: accessory.name];
        }
    }
    return cell;
}


#pragma mark - Table view delegate
- (void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    if(!samplePrintVC)
    {
        samplePrintVC = [[SamplePrintViewController alloc] initWithStyle:UITableViewStyleGrouped];
        [samplePrintVC setTitle:@"Printer Menu"];
        
    }
    if(!navControllerForSamplePrint)
    {
        navControllerForSamplePrint = [[UINavigationController alloc] initWithRootViewController: samplePrintVC];
    }
    if(printerListArray)
    {
        if(segmentedControl.selectedSegmentIndex == 0)
        {
            selectedIPAddr = [printerListArray objectAtIndex: indexPath.row];
            [wiredManager disconnectPrinter: connectedPrinter];
            connectedPrinter = nil;
            connectedPrinter = [wiredManager makeConnectWithSelectedPrinter:selectedIPAddr];
            [SimplePingHelper ping:selectedIPAddr
                            target:self sel:@selector(pingPrinterResult1:)];
            
        }else
        {
            selectedAccessory  = [printerListArray objectAtIndex: indexPath.row];
            [bluetoothManager disconnectPrinter: connectedPrinter];
            connectedPrinter = nil;
            connectedPrinter = [bluetoothManager makeConnectWithSelectedPrinter:selectedAccessory];
            [NSThread sleepForTimeInterval:2.0];
        }
        [self SendCommandToPrinter];
    }
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
        [NSThread sleepForTimeInterval:2.0f];
        dispatch_async(dispatch_get_main_queue(), ^{
            NSLog(@"Printer Status :%@",resultText);
            if(connectedPrinter.iPAddress){
                self.title = connectedPrinter.iPAddress;
                if([resultText isEqualToString:@"SUCCESS"]){
                    if(isPrinterAvailable)
                    {
                        if(connectedPrinter && [connectedPrinter.iPAddress isEqualToString:selectedIPAddr])
                        {
                            _connectedIP = NO;
                            [self tapPing];
                            [samplePrintVC setPrinter:connectedPrinter];
                            [samplePrintVC setPrinterIPAddress:selectedIPAddr];
                            [self.navigationController pushViewController:samplePrintVC animated:YES];
                            resultText = nil;
                        }
                    }else
                    {
                        [self failToSendAndOrReceive];                    }
                }else{
                    [self failToOpenPrinterAlert];
                }
            }
            else if(connectedPrinter.bluetoothAccessory){
                if(!isPrinterAvailable)
                    [self SendCommandToPrinter];
                self.title = connectedPrinter.bluetoothAccessory.name;
                if([selectedAccessory isEqual: connectedPrinter.bluetoothAccessory] && connectedPrinter.bluetoothAccessory.isConnected){
                    [self.navigationController pushViewController:samplePrintVC animated:YES];
                    [samplePrintVC setPrinter:connectedPrinter];
                }
                [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
                
            }else{
                [self failToOpenPrinterAlert];
            }
            
            [self.tableView deselectRowAtIndexPath:indexPath animated:YES];
            
        });
    });
}
- (void)failToSendAndOrReceive
{
    UIAlertView * alertView = [[UIAlertView alloc]
                               initWithTitle: @"Error"
                               message: @"Printer is busy\nFails to Send/Receive\n"
                               delegate: nil
                               cancelButtonTitle: @"OK" otherButtonTitles: nil];
    [alertView show];
}
- (void)failToOpenPrinterAlert
{
    UIAlertView * alertView = [[UIAlertView alloc]
                               initWithTitle: @"Error"
                               message: @"Fail to Open Printer"
                               delegate: nil
                               cancelButtonTitle: @"OK" otherButtonTitles: nil];
    [alertView show];
}
- (void)SendCommandToPrinter
{
    SAM4SPrintIO * posPrinter = (SAM4SPrintIO *)connectedPrinter.printIO;
    [posPrinter PrinterSetup];
    //    [posPrinter turnOFFASB];
    [posPrinter getPrinterStatus:TRUE];
    connectedPrinter.printIO.connection.delegate = self;
    [connectedPrinter.printIO.connection sendDataToPrinter:[posPrinter getDataTosend:posPrinter]];
}
- (UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    
    UILabel *sectionHeader = [[UILabel alloc] initWithFrame:CGRectNull];
    sectionHeader.hidden = YES;
    return sectionHeader;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    return 0;
}
- (void)MySegmentControlAction:(UISegmentedControl *)segment
{
    if(segment.selectedSegmentIndex == 0)
    {
        addToolbarView.hidden = NO;
        
    }else if (segment.selectedSegmentIndex == 1)
    {
        if([ipAddressTextField isFirstResponder])
            [ipAddressTextField resignFirstResponder];
        addToolbarView.hidden = YES;
        [self showBluetoothAccessoryPicker];
    }
//    sleep(2);
    [self availablePrinters];

}

#pragma mark - get conn & printer objects

- (void)tapPing
{
    if(!_connectedIP){
        if(selectedIPAddr)
        {
            [SimplePingHelper ping:selectedIPAddr
                            target:self sel:@selector(pingResult:)];
        }
    }
}
- (void)log:(NSString*)str {
    resultText = str;
    NSLog(@"Result :%@%@\n", selectedIPAddr, str);
    NSLog(@"Sam4sSDKResult :%@%@\n", selectedIPAddr, str);
}

- (void)pingPrinterResult1:(NSNumber*)success {
    if (success.boolValue) {
        [self log:@"SUCCESS"];
        count = 0;
    } else {
        if (count < 5) {
            [SimplePingHelper ping:selectedIPAddr
                            target:self sel:@selector(pingPrinterResult1:)];
            count = count + 1;
        }else{
            [self log:@"FAILURE"];
        }
    }
}

- (NSNumber *)pingResult:(NSNumber*)success
{
    //    Printer IP Address has to be pinged after selecting from the list. If it is manually disconnected, We can't ping the IP address
    //    if(!_connectedIP){
    if (success.boolValue && connectedPrinter.iPAddress)
    {
        count = 0;
        [NSTimer scheduledTimerWithTimeInterval:5.0 target:self selector:@selector(tapPing) userInfo:nil repeats:NO];
    } else
    {
        if (count < 5 && connectedPrinter.iPAddress) {
            [self tapPing];
            count = count + 1;
        }else { //only if 5 times ping fails
            [wiredManager disconnectPrinter: connectedPrinter];
            connectedPrinter = nil;
            selectedIPAddr = nil ;
            [self.tableView performSelectorOnMainThread: @selector(reloadData) withObject: nil waitUntilDone: NO];
            [self showAlert];
            count = 0;
            [[self.navigationController.view viewWithTag:20002]removeFromSuperview];
            [self.navigationController popToRootViewControllerAnimated:NO];
            
        }
        
    }
    //    }
    return success;
}
#pragma mark - alert view Delegate
- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
{
    if(alertView.tag == 100)
    {
        if([[alertView buttonTitleAtIndex:buttonIndex] isEqualToString:@"Dismiss"])
        {
            
        }
    }
}
#pragma mark - Disconnected Alert
-(void)showAlert
{
    alert = [[UIAlertView alloc]
             initWithTitle: @"Printer Disconnected"
             message: @""
             delegate: self
             cancelButtonTitle: @"Dismiss" otherButtonTitles: nil];
    alert.tag = 100;
    [alert show];
}
#pragma mark - refreshUI

- (void)didReceiveIPAddress : (NSArray *)discoveredIP
{
    NSLog(@"refreshUI discoveredIP: %@", discoveredIP);
    
        [printerListArray removeAllObjects];
        [printerListArray addObjectsFromArray:discoveredIP];
        NSLog(@"refreshUI %@", printerListArray);
    
        [self.tableView reloadData];
    
}

#pragma mark - get conn & printer objects

- (Printer*)getConnectedPrinter
{
    return connectedPrinter;
}


- (WiredConnectionManager*) getConnection
{
    return wiredManager;
}

- (BTConnectionManager*) getConnectionForBluetooth
{
    return bluetoothManager;
}
-(void) didReceivedDataFromPrinter:(NSData*) data
{
    if(data.length >0)
    {
        isPrinterAvailable = YES;
    }
}
@end

