//
//  StatusViewController.m
//  SHC
//
//  Created by Ambiga on 18/05/15.
//  Copyright (c) 2015 Ambiga. All rights reserved.
//

#import "StatusViewController.h"
#import "SAM4SPrintIO.h"
#import "PrintIOStream.h"

#define MASK_ASB1       0x93
#define MASK_ASB2       0x90
#define MASK_ASB3       0xf0
typedef enum __PRINTER_STATUS__
{
    /* No Error */
    STATUS_NO_ERROR = 0x00,
    /*Printer is online */
    STATUS_PRINTER_ONLINE = 0X01,
    /* Printer is offline */
    STATUS_PRINTER_OFFLINE = 0x02,
    /*Drawer open/close signal is LOW (connector pin 3)*/
    STATUS_DRAWER_OPEN = 0x03,
    STATUS_DRAWER_OPEN_HIGH = 0x04,
    STATUS_DRAWER_OPEN_LOW = 0x05,
    /*Drawer open/close signal is HIGH (connector pin 3).*/
    STATUS_DRAWER_CLOSED = 0x06,
    /* Cover is open */
    STATUS_PRINTER_COVER_OPEN = 0x07,
    /*Cover is closed */
    STATUS_PRINTER_COVER_CLOSED =  0x09,
    /*Paper is not being fed by using the PAPER FEED button*/
    STATUS_PAPERFEED_NOT_FED =  0x10,
    /* Paper is being fed by the PAPER FEED button*/
    STATUS_PAPERFEED_FED = 0x11,
    /*Printing stops due to paper end.*/
    STATUS_PAPER_END = 0x12,
    /*No paper-end stops*/
    STATUS_NO_PAPER = 0x13,
    /* Auto-cutter error occurs. */
    STATUS_ERROR_AUTO_CUTTER = 0x14,
    /*Unrecoverable error occurs.*/
    STATUS_ERROR_UNRECOVERABLE = 0x15,
    /*Auto recoverable error occurs*/
    STATUS_ERROR_AUTO_RECOVERABLE = 0x16,
    /*Paper roll near-end sensor. Paper adequate.*/
    STATUS_PAPER_ADEQUATE = 0x17,
    /*Paper near-end is detected by the paper roll near-end sensor.*/
    STATUS_PAPER_NEAR_END = 0x18,
    /*Not roll end sensor. Paper present.*/
    STATUS_NOT_ROLL_END_SENSOR = 0x19,
    /*Paper is detected by the paper roll end sensor.*/
    STATUS_PAPER_DETECTED = 0x20
}PRINTER_STATUS1;
@interface StatusViewController ()
{
//    NSString * tStatusCode;
//    NSString * tStatusDrawer;
//    NSString * tSaveStatusCode;
    int tSaveStatusCode;
}
@property (nonatomic, strong) NSMutableArray * mArrayResponse;
@end

@implementation StatusViewController
int tStatusCode=0;
int tStatusDrawer=0;
static int tStatusCodeOld=0;
@synthesize printer;
@synthesize mArrayResponse;

- (id)init{
    self = [super initWithStyle:UITableViewStyleGrouped];
    
    if(self)
    {
        statusArray =[NSArray arrayWithObjects:
                      @"All Status",
                      @"Drawer Status",
                      @"Cover Status",
                      @"Paper Status",
                      @"Near End Status",
                      nil];
        mArrayResponse = [[NSMutableArray alloc]initWithArray:[NSArray arrayWithObjects: @"Paper OK", @"Drawer Close", @"Cover Close", @"Paper OK", @"Paper OK", nil]];
        
        
    }
    
    return self;
    
}

//-(id) initWithStyle:(UITableViewStyle)style
//{
//    self = [super initWithStyle:UITableViewStyleGrouped];
//    if(self)
//    {
//    self = [self initWithStyle:style];
//    }
//    return self;
//}

- (void) loadView {
    [super loadView];
    self.navigationController.toolbarHidden = YES;
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
    
}


- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.view.backgroundColor = [UIColor groupTableViewBackgroundColor];
    self.automaticallyAdjustsScrollViewInsets = NO;
    CGSize statusBarSize = [[UIApplication sharedApplication] statusBarFrame].size;
    CGFloat h=MIN(statusBarSize.width, statusBarSize.height);
    UIEdgeInsets e = UIEdgeInsetsMake(self.navigationController.navigationBar.bounds.size.height - h + 6,
                                      0.0f,
                                      0.0f,
                                      0.0f);
    
    self.tableView.contentInset = e;
    
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)sendDataToPrinter
{
    SAM4SPrintIO *sam4sIO = (SAM4SPrintIO *)printer.printIO;
    printer.printIO.connection.delegate = self;
    [sam4sIO PrinterSetup];
//    [sam4sIO turnOFFASB];
    [sam4sIO getPrinterStatus:TRUE];
    [printer.printIO.connection sendDataToPrinter:[sam4sIO getDataTosend:sam4sIO]];
    [self.tableView reloadData];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:YES];
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
    self.navigationController.toolbarHidden = YES ;
    [self sendDataToPrinter];
}


#pragma mark - Table view data source & delegates

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [statusArray count];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"CellID";
    
    UITableViewCell *cell = (UITableViewCell *)[self.tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if(!cell)
    {
        cell = [[UITableViewCell alloc] initWithStyle: UITableViewCellStyleValue1 reuseIdentifier: CellIdentifier];
    }
    
    cell.textLabel.text = [statusArray objectAtIndex:indexPath.row];
    cell.detailTextLabel.text = [mArrayResponse objectAtIndex:indexPath.row];
    return cell;
}


-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return 70.0f;
}


-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [self sendDataToPrinter];
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

-(void) didReceivedDataFromPrinter:(NSData *)data
{
     tStatusCode=0;
     tStatusDrawer=0;
     tStatusCodeOld=0;

    unsigned char * bytePtr = (unsigned char  * )[data bytes];
    if ( (bytePtr[0] & MASK_ASB1) == 0x10 && (bytePtr[1] & MASK_ASB2) == 0x00 && (bytePtr[2] & MASK_ASB3) == 0x00 )
    {
        /////////////////////////////////////////////////////////////////////
        // Cash Drawer Compulsory Check
        //OutputDebugString(bytePtr[0]);
        if (bytePtr[0] & 0x04)
        {
            // 3pin High
            tStatusDrawer = STATUS_DRAWER_CLOSED;
            [mArrayResponse replaceObjectAtIndex:1 withObject:@"Drawer Close"];
        }
        else
        {
            tStatusDrawer = STATUS_DRAWER_OPEN;
            [mArrayResponse replaceObjectAtIndex:1 withObject:@"Drawer Open"];
        }
        
        if(tStatusCodeOld != tStatusDrawer)
        {
            tStatusCode = tStatusDrawer;
        }
        tStatusCodeOld =  tStatusDrawer;
        
        if (bytePtr[0] & 0x20)
        {
            tStatusCode = STATUS_PRINTER_COVER_OPEN;
            [mArrayResponse replaceObjectAtIndex:2 withObject:@"Cover Open"];
            [mArrayResponse replaceObjectAtIndex:0 withObject:@"Cover Open"];
        }
        else
        {
            if (tSaveStatusCode == STATUS_PRINTER_COVER_OPEN || ((bytePtr[0] == 0x14) && (bytePtr[1] == 0x00 )&& (bytePtr[2] == 0x00) &&( bytePtr[3] == 0x0f)))
            {
                tStatusCode = STATUS_PRINTER_COVER_CLOSED;
                [mArrayResponse replaceObjectAtIndex:2 withObject:@"Cover Close"];
                [mArrayResponse replaceObjectAtIndex:0 withObject:@"Cover Close"];

            }
            
        }
        
        if ( (bytePtr[2] & 0x0c) == 0x0c )
        {
            if((bytePtr[0] == 0x1c || bytePtr[0] == 0x14) && (bytePtr[1] == 0x00 )&& (bytePtr[2] == 0x0c) &&( bytePtr[3] == 0x0f))
            {
                [mArrayResponse replaceObjectAtIndex:2 withObject:@"Cover Close"];
                [mArrayResponse replaceObjectAtIndex:0 withObject:@"Cover Close"];
            }
            tStatusCode = STATUS_NO_PAPER;
            [mArrayResponse replaceObjectAtIndex:3 withObject:@"No Paper"];
            [mArrayResponse replaceObjectAtIndex:0 withObject:@"No Paper"];
        }
        else
        {
            if (tSaveStatusCode == STATUS_NO_PAPER)
            {
                tStatusCode = STATUS_PAPER_DETECTED;
                [mArrayResponse replaceObjectAtIndex:3 withObject:@"Paper OK"];
                [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper OK"];

            }
        }
        
        if ( (bytePtr[2] & 0x03) == 0x03 )
        {
            tStatusCode = STATUS_PAPER_NEAR_END;
            [mArrayResponse replaceObjectAtIndex:4 withObject:@"Paper Near End"];
            [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper Near End"];
        }
        else
        {
            if (tSaveStatusCode == STATUS_PAPER_NEAR_END)
            {
                tStatusCode = STATUS_PAPER_ADEQUATE;
                [mArrayResponse replaceObjectAtIndex:4 withObject:@"Paper OK"];
                [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper OK"];
            }
        }
    }
    else
    {
        tStatusCode = STATUS_NO_ERROR;
    }
    if(tStatusCode !=  STATUS_NO_ERROR)
    {
        tSaveStatusCode = tStatusCode;
    }
    NSLog(@"%d : %@",tStatusCode,mArrayResponse);
    [self.tableView reloadData];
}
//- (void)updateStatus
//{
//    /* No Error */
//    if(tStatusCode == 0)
//    {
//        
//    }
//    /*Printer is online */
//    else if(tStatusCode == 1)
//    {
//        
//    }
//    /* Printer is offline */
//    else if(tStatusCode == 2)
//    {
//        
//    }
//    /*Drawer open/close signal is LOW (connector pin 3)*/
//    else if(tStatusCode == 3)
//    {
//        
//    }else if(tStatusCode == 4)
//    {
//        
//    }else if(tStatusCode == 5)
//    {
//        
//    }
//    /*Drawer open/close signal is HIGH (connector pin 3).*/
//    else if(tStatusCode == 6)
//    {
//        [mArrayResponse replaceObjectAtIndex:1 withObject:@"Drawer Close"];
//    }    /* Cover is open */
//    else if(tStatusCode == 7)
//    {
//        [mArrayResponse replaceObjectAtIndex:2 withObject:@"Cover Open"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"Cover Open"];
//        
//    }else if(tStatusCode == 8)
//    {
//        
//    }
//    /*Cover is closed */
//    else if(tStatusCode == 9)
//    {
//        [mArrayResponse replaceObjectAtIndex:2 withObject:@"Cover Close"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"Cover Close"];
//    }
//    /*Paper is not being fed by using the PAPER FEED button*/
//    else if(tStatusCode == 10)
//    {
//        
//    }
//    /* Paper is being fed by the PAPER FEED button*/
//    else if(tStatusCode == 11)
//    {
//        
//    }
//    /*Printing stops due to paper end.*/
//    else if(tStatusCode == 12)
//    {
//        [mArrayResponse replaceObjectAtIndex:4 withObject:@"Paper Near End"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper Near End"];
//    }
//    /*No paper-end stops*/
//    else if(tStatusCode == 13)
//    {
//       
//    }
//    /* Auto-cutter error occurs. */
//    else if(tStatusCode == 14)
//    {
//        
//    }
//    /*Unrecoverable error occurs.*/
//    else if(tStatusCode == 15)
//    {
//        
//    }
//    /*Auto recoverable error occurs*/
//    else if(tStatusCode == 16)
//    {
//        
//    }
//    /*Paper roll near-end sensor. Paper adequate.*/
//    else if(tStatusCode == 17)
//    {
//        [mArrayResponse replaceObjectAtIndex:3 withObject:@"Paper Adequate"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper Adequate"];
//    }
//    /*Paper near-end is detected by the paper roll near-end sensor.*/
//    else if(tStatusCode == 18)
//    {
//        [mArrayResponse replaceObjectAtIndex:3 withObject:@"No Paper"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"No Paper"];
//    }
//    /*Not roll end sensor. Paper present.*/
//    else if(tStatusCode == 19)
//    {
//        [mArrayResponse replaceObjectAtIndex:3 withObject:@"No Paper"];
//        [mArrayResponse replaceObjectAtIndex:0 withObject:@"No Paper"];
////        [mArrayResponse replaceObjectAtIndex:3 withObject:@"Paper Present"];
////        [mArrayResponse replaceObjectAtIndex:0 withObject:@"Paper Present"];
//    }
//    /*Paper is detected by the paper roll end sensor.*/
//    else if(tStatusCode == 20)
//    {
//        
//    }
//}
@end
