//
//  TextPrintViewController.m
//  SHC
//
//  Created by Ambiga on 18/05/15.
//  Copyright (c) 2015 Ambiga. All rights reserved.
//

#import "TextPrintViewController.h"
#import "Printer.h"
#import "PrintIOStream.h"
#import "SAM4SPrintIO.h"

#define TREBUCHET_MS @"Trebuchet MS"


@interface TextPrintViewController ()
{
    NSMutableArray * mArrayFonts;
    NSMutableArray * mArrayAlign;
    NSMutableArray * mArrayLang;
    NSMutableArray * mArrayWidth;
    NSMutableArray * mArrayHeight;
    NSMutableArray * mArrayYpos;
    NSMutableArray * mArrayXpos;
    NSMutableArray * mArrayFeed;
    
    int nSelectedFont;
    int nSelectedAlignment;
    int nSelectedLang;
    NSString * nSelectedWidth;
    NSString * nSelectedHeight;
    NSString * nSelectedLineSpace;
    NSString * nSelectedXPos;
    NSString * nSelectedFeed;
    
    //UI to show and hide number pad for text fields
    UIToolbar *toolBar;
    UIBarButtonItem *barItemHideNumPad, *barItemClearText;
}
@end

@implementation TextPrintViewController

@synthesize printer;

- (instancetype) init
{
    self = [super init];
    
    if (self)
    {
        wiredManager = [ConnectionManager sharedConnectionWithType:ConnectionTypeWiFi delegate:self];

        fontPickerText = [UIFont fontWithName: TREBUCHET_MS size: 20];
    }
    
    return self;
}


- (void)loadView
{
    [super loadView];
    if ([self respondsToSelector:@selector(edgesForExtendedLayout)]) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        self.extendedLayoutIncludesOpaqueBars = NO;
        self.automaticallyAdjustsScrollViewInsets = NO;
    }
    self.navigationController.toolbarHidden = YES ;
    
    scrollview=[[UIScrollView alloc]initWithFrame:self.view.bounds];;
    scrollview.showsVerticalScrollIndicator=YES;
    scrollview.scrollEnabled=YES;
    scrollview.userInteractionEnabled=YES;
    CGSize scrollViewContentSize = CGSizeMake(320,1120);
    [scrollview setContentSize:scrollViewContentSize];
    [scrollview setBackgroundColor:[UIColor whiteColor]];
    scrollview.indicatorStyle = UIScrollViewIndicatorStyleBlack;
    [scrollview setDelegate:self];
    [self.view addSubview:scrollview];
    
    UITapGestureRecognizer *singleTap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(singleTapGestureCaptured:)];
    [scrollview addGestureRecognizer:singleTap];
    
    UILabel *printCharacters = [[UILabel alloc]initWithFrame:CGRectMake(self.view.frame.origin.x + 20, self.view.frame.origin.y + 5, 200,30)];
    [printCharacters setText:@"Print Characters"];
//    if([[UIDevice currentDevice].model containsString:@"iPhone"])
     if([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone)
        [printCharacters setFont:[UIFont fontWithName: @"Trebuchet MS" size: 18]];
    else
        [printCharacters setFont:[UIFont fontWithName: @"Trebuchet MS" size: 20]];
    [printCharacters setTextAlignment: NSTextAlignmentLeft];
    [printCharacters setBackgroundColor:[UIColor clearColor]];
    [printCharacters setTextColor: [UIColor blackColor]];

    [scrollview addSubview:printCharacters];
    //Textview to type the command
    commandText = [[UITextView alloc]initWithFrame:CGRectMake(self.view.frame.origin.x + 20, self.view.frame.origin.y + 5 + printCharacters.frame.size.height, self.view.frame.size.width - 40, self.view.frame.size.height/5)];
    commandText.layer.borderColor = [UIColor darkGrayColor].CGColor;
    commandText.layer.cornerRadius = 5;
    commandText.layer.borderWidth = 1;
    commandText.font = [UIFont systemFontOfSize:18];
    commandText.text = @"ELLIXstreet, SAM4Scity, SHCstate\nTEL 9999-99-999 c #2\nMarch.01, 2013 PM4.24\n apples            $20.00\n grapes            $30.00\n bananas         $40.00\n lemons           $50.00\n oranges          $60.00\n Tax excluded  $200.00\n Tax 5.0%        $10.00\n _________________________________\n Total                $210.00";
//    commandText.text = @"0123456789\nABCDEFGHIJKLMNOPQRSTUVWXYZ";

    commandText.textColor = [UIColor blackColor];
    commandText.returnKeyType = UIReturnKeyDefault;
    commandText.editable = YES;
    commandText.delegate = self;
    [scrollview addSubview:commandText];
  
    //fonts
    fontBold = [UIFont fontWithName: @"TrebuchetMS-Italic" size: 17];
    fontUnderline = [UIFont fontWithName: @"TrebuchetMS-Italic" size: 17];
    fontNormal = [UIFont fontWithName: @"Trebuchet MS" size: 17];
    UILabel *label;
//    if([[UIDevice currentDevice].model containsString:@"iPhone"])
    if([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPhone)

    {
       label = [[UILabel alloc] initWithFrame: CGRectMake(self.view.frame.origin.x + 20,  commandText.frame.size.height + 715,  200, 30)];
        [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 18]];
         boldButton = [[UIButton alloc]initWithFrame: CGRectMake(self.view.frame.origin.x + 20,  label.frame.origin.y + label.frame.size.height + 10,  50, 50)];
         printButton = [[UIButton alloc]initWithFrame: CGRectMake(((self.view.frame.size.width - (self.view.frame.size.width/2)) /2),boldButton.frame.origin.y + boldButton.frame.size.height + 30, scrollview.frame.size.width /2, 50)];
    }
    else
    {
       label = [[UILabel alloc] initWithFrame: CGRectMake(self.view.frame.origin.x + 20,  commandText.frame.size.height + 455,  200, 30)];
        [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 20]];
         boldButton = [[UIButton alloc]initWithFrame: CGRectMake(self.view.frame.origin.x + 20,  label.frame.origin.y + label.frame.size.height + 10,  50, 50)];
        printButton = [[UIButton alloc]initWithFrame: CGRectMake(((self.view.frame.size.width - (self.view.frame.size.width/2)) /2), self.view.frame.origin.y + self.view.frame.size.height - 134, scrollview.frame.size.width /2, 50)];
    }
    
    [label setText:@"Style"];
    [label setTextAlignment: NSTextAlignmentLeft];
    [label setBackgroundColor:[UIColor clearColor]];
    [label setTextColor: [UIColor blackColor]];
    [scrollview addSubview:label];
    
   
    [boldButton setImage:[UIImage imageNamed:@"text_bold.png"] forState:UIControlStateNormal];
    [boldButton addTarget:self action:@selector(toggleButtonState:) forControlEvents:UIControlEventTouchUpInside];
    boldButton.layer.cornerRadius = 5;
    boldButton.layer.borderWidth = 0;
    boldButton.layer.borderColor = [UIColor lightGrayColor].CGColor;
    boldButton.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    [boldButton setAlpha: 0.3f];
    [scrollview addSubview:boldButton];

    underlineButton = [[UIButton alloc]initWithFrame: CGRectMake(self.view.frame.origin.x + boldButton.frame.size.width + 50,  boldButton.frame.origin.y, 50, 50)];
    [underlineButton setImage:[UIImage imageNamed:@"text_underline.png"] forState:UIControlStateNormal];
    [underlineButton addTarget:self action:@selector(toggleButtonState:) forControlEvents:UIControlEventTouchUpInside];
    [underlineButton setAlpha: 0.3f];
    underlineButton.layer.cornerRadius = 5;
    underlineButton.layer.borderWidth = 0;
    underlineButton.layer.borderColor = [UIColor lightGrayColor].CGColor;
    underlineButton.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    [scrollview addSubview:underlineButton];
    
   
    [printButton setTitle:@"Print" forState:UIControlStateNormal];
    printButton.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    printButton.backgroundColor = [UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0];
    [printButton addTarget:self action:@selector(sendCommandToPrinter) forControlEvents:UIControlEventTouchUpInside];
    [scrollview addSubview:printButton];
    
    commandText.delegate = self;

}

- (void) loadToolbar
{
    NSDictionary *attributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                [UIFont fontWithName: TREBUCHET_MS size: 18], NSFontAttributeName,
                                [UIColor darkGrayColor], NSForegroundColorAttributeName,
                                nil];
    
    //toolbar
    UIBarButtonItem *barItemSpace = [[UIBarButtonItem alloc]
                                     initWithBarButtonSystemItem: UIBarButtonSystemItemFlexibleSpace
                                     target: nil
                                     action: nil];
    
    barItemHideNumPad = [[UIBarButtonItem alloc]
                         initWithTitle: @"Done"
                         style: UIBarButtonItemStyleDone
                         target: self
                         action: nil];
    [barItemHideNumPad setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    barItemClearText = [[UIBarButtonItem alloc]
                        initWithTitle: @"Clear"
                        style: UIBarButtonItemStyleDone
                        target: self
                        action: nil];
    [barItemClearText setTitleTextAttributes: attributes forState: UIControlStateNormal];
    
    const float heightToolbar = 40.0f;
    toolBar = [[UIToolbar alloc] initWithFrame:
               CGRectMake(0, 0, self.view.frame.size.width, heightToolbar)];
    [toolBar setItems: [NSArray arrayWithObjects:
                        barItemHideNumPad, barItemSpace,
                        barItemClearText, nil]];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    self.view.backgroundColor = [UIColor groupTableViewBackgroundColor];
    
    [self updateTextPrinterUI];
}

-(void) updateTextPrinterUI
{
    mArrayFonts = [[NSMutableArray alloc] initWithArray:[NSArray arrayWithObjects:@"FONT_A",@"FONT_B",nil]];
    mArrayAlign = [[NSMutableArray alloc] initWithArray:[NSArray arrayWithObjects:@"LEFT",@"CENTRE",@"RIGHT",nil]];
    mArrayLang = [[NSMutableArray alloc] initWithArray:[NSArray arrayWithObjects:@"ENG",@"KOR", nil]];
    mArrayWidth = [[NSMutableArray alloc] initWithArray:[NSArray arrayWithObjects:@"1",@"2",@"3",@"4",@"5",@"6",@"7",@"8", nil]];
    mArrayHeight = [[NSMutableArray alloc] initWithArray:[NSArray arrayWithObjects:@"1",@"2",@"3",@"4",@"5",@"6",@"7",@"8", nil]];
    mArrayXpos = [[NSMutableArray alloc] init];
    mArrayYpos = [[NSMutableArray alloc] init];
    mArrayFeed = [[NSMutableArray alloc] init];
    
    for (int i = 0; i <= 255; i++)
    {
        [mArrayXpos addObject:[NSString stringWithFormat:@"%d", i]];
        [mArrayYpos addObject:[NSString stringWithFormat:@"%d", i]];
        [mArrayFeed addObject:[NSString stringWithFormat:@"%d", i]];
    }
//    if([[UIDevice currentDevice].model containsString:@"iPhone"])
    if([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPhone)
    {
    CGRect rect = CGRectMake(self.view.frame.origin.x + 20, commandText.frame.size.height + 75, self.view.frame.size.width/4+5, 100);
    for (int i = 0; i <= 7; i++)
    {
        UIPickerView * pickerView =  [[UIPickerView alloc]initWithFrame:rect];
        pickerView.delegate = self;
        pickerView.dataSource = self;
        pickerView.tag = i;
        [pickerView.layer setBorderColor: [UIColor darkGrayColor].CGColor];
        [pickerView.layer setBorderWidth: 1.0f];
        [pickerView.layer setCornerRadius: 5.0f];
        [scrollview addSubview:pickerView];
        
        UILabel *label = [[UILabel alloc] initWithFrame: CGRectMake(pickerView.frame.origin.x, pickerView.frame.origin.y - 27, pickerView.frame.size.width, 22)];
        NSString * string = nil;
        switch (i) {
            case 0:
                string = @"Font";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedFont =(int)[pickerView selectedRowInComponent:0];
                break;
                
            case 1:
                string = @"Alignment";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedAlignment =(int)[pickerView selectedRowInComponent:0];
                break;
                
            case 2:
                string = @"Language";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedLang =(int)[pickerView selectedRowInComponent:0];
                break;
                
            case 3:
                string = @"Width";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedWidth =[mArrayWidth objectAtIndex:0];
                break;
                
            case 4:
                string = @"Height";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedHeight =[mArrayHeight objectAtIndex:0];
                break;
                
            case 5:
                string = @"LineSpace";
                [pickerView selectRow:30 inComponent:0 animated:YES];
                nSelectedLineSpace =[mArrayYpos objectAtIndex:30];
                break;
                
            case 6:
                string = @"X Pos";
                [pickerView selectRow:0 inComponent:0 animated:YES];
                nSelectedXPos =[mArrayXpos objectAtIndex:0];
                break;
                
            case 7:
                string = @"Feed";
                [pickerView selectRow:30 inComponent:0 animated:YES];
                nSelectedFeed =[mArrayFeed objectAtIndex:30];
                break;
                
            default:
                break;
        }
        
        [label setText:string];
        [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 18]];
        [label setTextAlignment: NSTextAlignmentCenter];
        [label setBackgroundColor:[UIColor clearColor]];
        [label setTextColor: [UIColor blackColor]];
        [scrollview addSubview:label];
        rect.origin.x += rect.size.width + 15;
        
        if(i == 2 || i == 5)
        {
            rect.origin.y += commandText.frame.size.height + 90;
            rect.origin.x = self.view.frame.origin.x + 20;
        }
    }
    }
//    if([[UIDevice currentDevice].model containsString:@"iPad"])
    else
    {
        CGRect rect = CGRectMake(self.view.frame.origin.x + 20, commandText.frame.size.height + 75, self.view.frame.size.width/6, 100);
        for (int i = 0; i <= 7; i++)
        {
            UIPickerView * pickerView =  [[UIPickerView alloc]initWithFrame:rect];
            pickerView.delegate = self;
            pickerView.dataSource = self;
            pickerView.tag = i;
            [pickerView.layer setBorderColor: [UIColor darkGrayColor].CGColor];
            [pickerView.layer setBorderWidth: 1.0f];
            [pickerView.layer setCornerRadius: 5.0f];
            [scrollview addSubview:pickerView];
            
            UILabel *label = [[UILabel alloc] initWithFrame: CGRectMake(pickerView.frame.origin.x, pickerView.frame.origin.y - 27, pickerView.frame.size.width, 22)];
            NSString * string = nil;
            switch (i) {
                case 0:
                    string = @"Font";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedFont =(int)[pickerView selectedRowInComponent:0];
                    break;
                    
                case 1:
                    string = @"Alignment";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedAlignment =(int)[pickerView selectedRowInComponent:0];
                    break;
                    
                case 2:
                    string = @"Language";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedLang =(int)[pickerView selectedRowInComponent:0];
                    break;
                    
                case 3:
                    string = @"Width";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedWidth =[mArrayWidth objectAtIndex:0];
                    break;
                    
                case 4:
                    string = @"Height";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedHeight =[mArrayHeight objectAtIndex:0];
                    break;
                    
                case 5:
                    string = @"LineSpace";
                    [pickerView selectRow:30 inComponent:0 animated:YES];
                    nSelectedLineSpace =[mArrayYpos objectAtIndex:30];
                    break;
                    
                case 6:
                    string = @"X Pos";
                    [pickerView selectRow:0 inComponent:0 animated:YES];
                    nSelectedXPos =[mArrayXpos objectAtIndex:0];
                    break;
                    
                case 7:
                    string = @"Feed";
                    [pickerView selectRow:30 inComponent:0 animated:YES];
                    nSelectedFeed =[mArrayFeed objectAtIndex:30];
                    break;
                    
                default:
                    break;
            }
            
            [label setText:string];
            [label setFont:[UIFont fontWithName: @"Trebuchet MS" size: 20]];
            [label setTextAlignment: NSTextAlignmentCenter];
            [label setBackgroundColor:[UIColor clearColor]];
            [label setTextColor: [UIColor blackColor]];
            [scrollview addSubview:label];
            rect.origin.x += rect.size.width + 20;
            
            if(i == 4)
            {
                rect.origin.y += commandText.frame.size.height;
                rect.origin.x = self.view.frame.origin.x + 20;
            }
        }

    }
    
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:YES];
    self.navigationController.toolbarHidden = YES ;
  
}

- (void)viewWillDisappear:(BOOL)animated{
    [super viewWillDisappear:YES];
    [commandText resignFirstResponder];
}


- (void)viewDidAppear{
    [super viewDidAppear:YES];
    commandText.delegate = self;
    [commandText resignFirstResponder];

}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


#pragma mark - Tap Gesture Method

- (void)singleTapGestureCaptured:(UITapGestureRecognizer *)gesture
{
    [scrollview endEditing:YES];
    [commandText resignFirstResponder];
}


- (void) toggleBoldface
{
    [self toggleButtonState: boldButton];
    if(boldButton.isSelected)
    {
        [commandText setFont: fontBold];
    }
    else
    {
        [commandText setFont: fontNormal];
    }
}


- (void) toggleUnderline
{
    [self toggleButtonState: underlineButton];
    if(underlineButton.isSelected)
    {
        [commandText setFont: fontUnderline];
    }
    else
    {
        [commandText setFont: fontNormal];
    }

}


- (void) toggleButtonState: (UIButton*)button
{
    [button setSelected: !button.selected];
    [button setAlpha: (button.isSelected? 1.0f : 0.3f)];
}


#pragma mark TextField Delegates
- (BOOL) textViewShouldBeginEditing:(UITextView *)textView
{
    if(commandText)
    {
        if(!toolBar)
        {
            [self loadToolbar];
        }
        
        [barItemHideNumPad setTarget: textView];
        [barItemHideNumPad setAction: @selector(resignFirstResponder)];
        
        [barItemClearText setTarget: self];
        [barItemClearText setAction: @selector(clearText)];
        
        [textView setInputAccessoryView: toolBar];
    }
    
    return YES;
}

- (void) clearText
{
    commandText.text = nil;
}

- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event{
    [self.view endEditing:YES];
    [scrollview endEditing:YES];
    [super touchesBegan:touches withEvent:event];
}


- (BOOL)textFieldShouldBeginEditing:(UITextField *)textField
{
    return YES;
}


- (BOOL)textFieldShouldEndEditing:(UITextField *)textField
{
    return YES;
}


- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [commandText resignFirstResponder];
    return YES;
}

-(void) textFieldDidBeginEditing:(UITextField *)textView
{
    NSLog(@"%f",self.view.frame.origin.y);
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.25f];
    CGRect frame = self.view.frame;
    frame.origin.y =frame.origin.y - 170;
    [self.view setFrame:frame];
    [UIView commitAnimations];
}


-(void) textFieldDidEndEditing:(UITextField *)textView
{
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.25f];
    CGRect frame = self.view.frame;
    frame.origin.y = frame.origin.y + 170;
    [self.view setFrame:frame];
    [UIView commitAnimations];
}
#pragma mark - UIScrollViewDelegate
- (void)scrollViewDidScroll:(UIScrollView *)scrollView
{
    [self changeScrollBarColorFor:scrollView];
}

- (void)changeScrollBarColorFor:(UIScrollView *)scrollView
{
    for ( UIView *view in scrollView.subviews ) {
        
        if (view.tag == 0 && [view isKindOfClass:UIImageView.class])
        {
            
            UIImageView *imageView = (UIImageView *)view;
            imageView.backgroundColor = [UIColor colorWithRed:85.0/255.0 green:143.0/255.0 blue:220.0/255.0 alpha:1.0];
        }
    }
}
#pragma mark - Text View View Delegates
- (void)textViewDidBeginEditing:(UITextView *)textView
{
    //Implementation not required
}


- (void)textViewDidEndEditing:(UITextView *)textView{
   commandText.text = textView.text ;
}


- (BOOL)textView:(UITextView *)textView shouldChangeTextInRange:(NSRange)range
 replacementText:(NSString *)text
{
    // Any new character added is passed in as the "text" parameter
    if ([text isEqualToString:@"\n"]) {
        // Be sure to test for equality using the "isEqualToString" message
        [commandText insertText:text];
        // Return FALSE so that the final '\n' character doesn't get added
        return FALSE;
    }
    // For any other character return TRUE so that the text gets added to the view
    return TRUE;
}

#pragma mark - Picker View Delegates
- (UIView*) pickerView: (UIPickerView*)pickerView viewForRow: (NSInteger)row forComponent: (NSInteger)component reusingView: (UIView*)view
{
    NSString *pickerText = nil;
    
    switch (pickerView.tag)
    {
        case 0:
            pickerText = [mArrayFonts objectAtIndex:row];
            break;
            
        case 1:
            pickerText = [mArrayAlign objectAtIndex:row];
            break;
            
        case 2:
            pickerText = [mArrayLang objectAtIndex:row];
            break;
            
        case 3:
            pickerText = [mArrayWidth objectAtIndex:row];
            break;
            
        case 4:
            pickerText = [mArrayHeight objectAtIndex:row];
            break;
            
        case 5:
            pickerText = [mArrayYpos objectAtIndex:row];
            break;
            
        case 6:
            pickerText = [mArrayXpos objectAtIndex:row];
            break;
            
        case 7:
            pickerText = [mArrayFeed objectAtIndex:row];
            break;
            
        default:
            break;
    }
    
    UILabel *label = [[UILabel alloc] initWithFrame: CGRectMake(0, 0, widthPicker, 40)];
    [label setText: pickerText];
    [label setFont: fontPickerText];
    [label setTextAlignment: NSTextAlignmentCenter];
    [label setTextColor: [UIColor blackColor]];
    
    return  label;
    
}


- (NSInteger) pickerView: (UIPickerView*)pickerView numberOfRowsInComponent: (NSInteger)component
{
    NSInteger numRows = 0;
    
    switch (pickerView.tag)
    {
        case 0:
            numRows = [mArrayFonts count];
            break;
            
        case 1:
            numRows = [mArrayAlign count];
            break;
            
        case 2:
            numRows = [mArrayLang count];
            break;
            
        case 3:
            numRows = [mArrayWidth count];
            break;
            
        case 4:
            numRows = [mArrayHeight count];
            break;
        case 5:
            numRows = [mArrayYpos count];
            break;
            
        case 6:
            numRows = [mArrayXpos count];
            break;
            
        case 7:
            numRows = [mArrayFeed count];
            break;
            
        default:
            break;
    }
    return numRows;
}


- (NSInteger) numberOfComponentsInPickerView: (UIPickerView *)pickerView
{
    return 1;
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    // This method is triggered whenever the user makes a change to the picker selection.
    // The parameter named row and component represents what was selected.
    
    switch (pickerView.tag)
    {
        case 0:
            nSelectedFont = (int)[pickerView selectedRowInComponent:0];
            break;
            
        case 1:
            nSelectedAlignment = (int)[pickerView selectedRowInComponent:0];
            break;
            
        case 2:
            nSelectedLang = (int)[pickerView selectedRowInComponent:0];
            break;
            
        case 3:
            nSelectedWidth = [mArrayWidth objectAtIndex:row];
            break;
            
        case 4:
            nSelectedHeight = [mArrayHeight objectAtIndex:row];
            break;
        case 5:
            nSelectedLineSpace = [mArrayYpos objectAtIndex:row];
            break;
            
        case 6:
            nSelectedXPos = [mArrayXpos objectAtIndex:row];
            break;
            
        case 7:
            nSelectedFeed = [mArrayFeed objectAtIndex:row];
            break;
            
        default:
            break;
    }
}

- (void)sendCommandToPrinter
{
    if(printer)
    {
        if(commandText.text.length > 0){
        SAM4SPrintIO *sam4sIO = (SAM4SPrintIO *)printer.printIO;
        printer.printIO.connection.delegate = self;
        [sam4sIO PrinterSetup];
        [sam4sIO addTextFont:nSelectedFont];
        [sam4sIO addTextAlignment:nSelectedAlignment];
        [sam4sIO addTextPosition:[nSelectedXPos intValue]];
        [sam4sIO addLineSpace:[nSelectedLineSpace intValue]];
        [sam4sIO addTextLanguage:nSelectedLang];
        [sam4sIO addTextSize:[nSelectedWidth intValue] :[nSelectedHeight intValue]];
        [sam4sIO addTextStyle:NO :underlineButton.selected :boldButton.selected :COLOR_1];
        [sam4sIO addTextData:commandText.text];
        [sam4sIO addFeedUnit:[nSelectedFeed intValue]];
        [printer.printIO.connection sendDataToPrinter:[sam4sIO getDataTosend:sam4sIO]];
        }else{
            
               UIAlertView * alert = [[UIAlertView alloc]
                         initWithTitle: @"Error"
                         message: @"No text to print"
                         delegate: self
                         cancelButtonTitle: @"Dismiss" otherButtonTitles: nil];
                alert.tag = 100;
                [alert show];
 
        }
    }
}

-(void) didReceivedDataFromPrinter:(NSData*)data
{
    NSLog(@"data = %@", [data description]);
}
@end

